@@ -43,6 +43,20 @@ describe('CSON.stringify', () => {
       cson(`\
 I am your average multi-line string,
 and I have a sneaky ''' in here, too\
+`)
+    ));
+
+  it('handles multi-line strings with quad quotes', () =>
+    equal(
+      `\
+'''
+  I am your average multi-line string,
+  and I have a sneaky \\''\\'' in here, too
+'''\
+`,
+      cson(`\
+I am your average multi-line string,
+and I have a sneaky '''' in here, too\
 `)
     ));
 
